#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-09-26
# File  : metrics/cisco_cellular_lte.py
#
# Cisco Cellular LTE metrics plugin
#
# 2022-11-10: fixed range for RSRP and RSRQ
#             added range for RSSI
#             added scalars for all
#
from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info
)

metric_info['cisco_cellular_rsrp'] = {
    'title': _('RSRP'),
    'unit': 'dbm',
    'color': '22/a',
}
metric_info['cisco_cellular_rsrq'] = {
    'title': _('RSRQ'),
    'unit': 'db',
    'color': '32/a',
}
metric_info['cisco_cellular_rssi'] = {
    'title': _('RSSI'),
    'unit': 'dbm',
    'color': '42/a',
}

graph_info['cisco_cellular.rsrp'] = {
    'title': _('Reference Signal Received Power'),
    'metrics': [
        ('cisco_cellular_rsrp', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rsrp:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrp:warn,-1,*', 'Warning'),
    ],
    'range': ('cisco_cellular_rsrp:max,-', 1),
}

graph_info['cisco_cellular.rsrq'] = {
    'title': _('Reference Signal Received Quality'),
    'metrics': [
        ('cisco_cellular_rsrq', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rsrq:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrq:warn,-1,*', 'Critical'),
    ],
     'range': ('cisco_cellular_rsrq:max,-', 1),
}

graph_info['cisco_cellular.rssi'] = {
    'title': _('Received Signal Strength Indicator'),
    'metrics': [
        ('cisco_cellular_rssi', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rssi:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrq:warn,-1,*', 'Critical'),
    ],
    'range': ('cisco_cellular_rssi:max,-', 1)
}
